@@ -71,7 +71,7 @@ class TreeDocumentContent(TreeNode, AbstractTreeDocumentContent):
         return self._text
 
     @property
-    def language(self) -> str:
+    def language(self) -> Optional[str]:
         return self._language
 
     def get_node_text_translation(self, lang: str) -> str:
@@ -83,7 +83,7 @@ class TreeDocumentContent(TreeNode, AbstractTreeDocumentContent):
     def node_text_languages(self) -> Set[str]:
         return set(self._text_translations.keys())
 
-    def with_language(self, language: str):
+    def with_language(self, language: Optional[str]):
         return self._with_changes(language=language)
 
     def without_language(self):
